nanoget
=======

| This module provides functions to extract useful metrics from Oxford
  Nanopore sequencing reads and alignments.
| Data can be presented in the following formats:
| - A sorted bam file ``processBam(bamfile, threads)``
| - A standard fastq file ``processFastqPlain(fastqfile)``
| - A fastq file with metadata from MinKNOW or Albacore
  ``processFastq_rich(fastqfile)``
| - A sequencing\_summary file generated by Albacore
  ``processSummary(sequencing_summary.txt)``

Fastq files can be compressed using gzip, bzip2 or bgzip. The data is
returned as a pandas DataFrame with standardized headernames for
convenient extraction. The functions perform logging while being called
and extracting data.
